==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ConfigurationServiceGitPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Property of git environment.
 * @property repositories Repositories of Application Configuration Service git property.
 */
public data class ConfigurationServiceGitPropertyArgs(
    public val repositories: Output<List<ConfigurationServiceGitRepositoryArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs =
        com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs.builder()
            .repositories(
                repositories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConfigurationServiceGitPropertyArgs].
 */
@PulumiTagMarker
public class ConfigurationServiceGitPropertyArgsBuilder internal constructor() {
    private var repositories: Output<List<ConfigurationServiceGitRepositoryArgs>>? = null

    /**
     * @param value Repositories of Application Configuration Service git property.
     */
    @JvmName("rboojsbmenifakou")
    public suspend fun repositories(`value`: Output<List<ConfigurationServiceGitRepositoryArgs>>) {
        this.repositories = value
    }

    @JvmName("deqqgjdnftjrchyg")
    public suspend fun repositories(vararg values: Output<ConfigurationServiceGitRepositoryArgs>) {
        this.repositories = Output.all(values.asList())
    }

    /**
     * @param values Repositories of Application Configuration Service git property.
     */
    @JvmName("gaqqxdgdluwlnqsy")
    public suspend fun repositories(values: List<Output<ConfigurationServiceGitRepositoryArgs>>) {
        this.repositories = Output.all(values)
    }

    /**
     * @param value Repositories of Application Configuration Service git property.
     */
    @JvmName("tqkixylrioagirhl")
    public suspend fun repositories(`value`: List<ConfigurationServiceGitRepositoryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("vimeihuksxjhahrq")
    public suspend
    fun repositories(argument: List<suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("hlqwurqsyorybvxf")
    public suspend fun repositories(
        vararg
        argument: suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("ytbogaelugpwmfxv")
    public suspend
    fun repositories(argument: suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param values Repositories of Application Configuration Service git property.
     */
    @JvmName("geavdoiqunmygdmd")
    public suspend fun repositories(vararg values: ConfigurationServiceGitRepositoryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.repositories = mapped
    }

    internal fun build(): ConfigurationServiceGitPropertyArgs = ConfigurationServiceGitPropertyArgs(
        repositories = repositories,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ConfigurationServiceGitPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Property of git environment.
 * @property repositories Repositories of Application Configuration Service git property.
 */
public data class ConfigurationServiceGitPropertyArgs(
    public val repositories: Output<List<ConfigurationServiceGitRepositoryArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs =
        com.pulumi.azurenative.appplatform.inputs.ConfigurationServiceGitPropertyArgs.builder()
            .repositories(
                repositories?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConfigurationServiceGitPropertyArgs].
 */
@PulumiTagMarker
public class ConfigurationServiceGitPropertyArgsBuilder internal constructor() {
    private var repositories: Output<List<ConfigurationServiceGitRepositoryArgs>>? = null

    /**
     * @param value Repositories of Application Configuration Service git property.
     */
    @JvmName("lcbcfrjhoguskdhl")
    public suspend fun repositories(`value`: Output<List<ConfigurationServiceGitRepositoryArgs>>) {
        this.repositories = value
    }

    @JvmName("annsogkkgcuicxoe")
    public suspend fun repositories(vararg values: Output<ConfigurationServiceGitRepositoryArgs>) {
        this.repositories = Output.all(values.asList())
    }

    /**
     * @param values Repositories of Application Configuration Service git property.
     */
    @JvmName("pkinwkcnqvgdewui")
    public suspend fun repositories(values: List<Output<ConfigurationServiceGitRepositoryArgs>>) {
        this.repositories = Output.all(values)
    }

    /**
     * @param value Repositories of Application Configuration Service git property.
     */
    @JvmName("dwlgymnswyktykdd")
    public suspend fun repositories(`value`: List<ConfigurationServiceGitRepositoryArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("spiwpgsehxwojxvt")
    public suspend
    fun repositories(argument: List<suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("cybqscafkmskpvsr")
    public suspend fun repositories(
        vararg
        argument: suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param argument Repositories of Application Configuration Service git property.
     */
    @JvmName("icxnuijbovdbsjuq")
    public suspend
    fun repositories(argument: suspend ConfigurationServiceGitRepositoryArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConfigurationServiceGitRepositoryArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.repositories = mapped
    }

    /**
     * @param values Repositories of Application Configuration Service git property.
     */
    @JvmName("qloulrbtstnykbjy")
    public suspend fun repositories(vararg values: ConfigurationServiceGitRepositoryArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.repositories = mapped
    }

    internal fun build(): ConfigurationServiceGitPropertyArgs = ConfigurationServiceGitPropertyArgs(
        repositories = repositories,
    )
}
